@@ -194,6 +194,14 @@ class UpdateService(mixins.UpdateModelMixin, GenericService):
     pass
 
 
+class ListCreateService(mixins.ListModelMixin, mixins.CreateModelMixin, GenericService):
+    """
+    Concrete service for listing a queryset that provides a ``List()`` and ``Create()`` handler.
+    """
+
+    pass
+
+
 class ReadOnlyModelService(mixins.RetrieveModelMixin, mixins.ListModelMixin, GenericService):
     """
     Concrete service that provides default ``List()`` and ``Retrieve()``
@@ -274,6 +282,16 @@ class AsyncUpdateService(mixins.AsyncUpdateModelMixin, GenericService):
     pass
 
 
+class AsyncListCreateService(
+    mixins.AsyncListModelMixin, mixins.AsyncCreateModelMixin, GenericService
+):
+    """
+    Concrete service for listing a queryset that provides a ``List()`` and ``Create()`` handler.
+    """
+
+    pass
+
+
 class AsyncReadOnlyModelService(
     mixins.AsyncRetrieveModelMixin, mixins.AsyncListModelMixin, GenericService
 ):
